@@ -11,6 +11,10 @@ use openssl::hash::MessageDigest;
 
 pub async fn init(email:Email,conn:&Connection)->Result<(Vec<String>,String,u64),&'static str>{
 
+    if email.receivers.len() == 0{
+        return Err("not_found-receivers-parse_email");
+    }
+
     let mut commands = vec![];
     let mut headers = String::new();
     let mut dkim_headers = String::new();
@@ -26,7 +30,10 @@ pub async fn init(email:Email,conn:&Connection)->Result<(Vec<String>,String,u64)
         headers.push_str(&format!("FROM: <{}>\r\n",email.from));
         dkim_headers.push_str(&format!("from:<{}>\r\n",email.from));
     }
-    commands.push(format!("RCPT TO:<{}>\r\n",email.to));
+    for i in email.receivers.iter(){
+        commands.push(format!("RCPT TO:<{}>\r\n",i));
+    }
+    // commands.push(format!("RCPT TO:<{}>\r\n",email.to));
     commands.push(format!("DATA\r\n"));
 
     
@@ -39,14 +46,23 @@ pub async fn init(email:Email,conn:&Connection)->Result<(Vec<String>,String,u64)
         dkim_headers.push_str(&format!("message-id:<{}>\r\n",email.unique_id));
     }
 
+    let mut to_value = String::new();
+    for i in email.to{
+        if to_value.len() == 0{
+            to_value += &format!("{}",i);
+        } else {
+            to_value += &format!(", {}",i);
+        }
+    }
+
     headers.push_str(&format!("Date: {}\r\n",email.date));
     headers.push_str(&format!("Subject: {}\r\n",email.subject));
-    headers.push_str(&format!("To: {}\r\n",email.to));
+    headers.push_str(&format!("To: {}\r\n",to_value));
     headers.push_str(&format!("DKIM-Signature: ===dkim===\r\n"));
 
     dkim_headers.push_str(&format!("date:{}\r\n",email.date));
     dkim_headers.push_str(&format!("subject:{}\r\n",email.subject));
-    dkim_headers.push_str(&format!("to:{}\r\n",email.to));
+    dkim_headers.push_str(&format!("to:{}\r\n",to_value));
 
     if email.body.len() == 0 && email.html.len() == 0{
         return Err("invalid_email_body");
@@ -190,6 +206,8 @@ pub async fn init(email:Email,conn:&Connection)->Result<(Vec<String>,String,u64)
     size += commands[2].len() as u64;
     size += commands[3].len() as u64;
 
+    // println!("{:?}",commands);
+
     return Ok((commands,email.tracking_id,size));
 
 }
